@@ -105,39 +105,50 @@ on_layout_size_allocate (GtkWidget *widget, GtkAllocation *alloc, GladeDesignVie
   g_signal_handlers_disconnect_by_func (widget, on_layout_size_allocate, view);
 }
 
+static void
+glade_design_view_update_state (GList *objects, GtkStateFlags state)
+{
+  GList *l;
+
+  for (l = objects; l && l->data; l = g_list_next (l))
+    {
+      GtkWidget *view, *widget = l->data;
+
+      if (GTK_IS_WIDGET (widget) &&
+          gtk_widget_get_visible (widget) &&
+          (view = gtk_widget_get_ancestor (widget, GLADE_TYPE_DESIGN_LAYOUT)))
+        {
+          gtk_widget_set_state_flags (view, state, TRUE);
+        }
+    }
+}
+
 static void
 glade_design_view_selection_changed (GladeProject *project, GladeDesignView *view)
 {
+  GtkWidget *layout;
   GList *selection;
 
+  glade_design_view_update_state (glade_project_toplevels (project),
+                                  GTK_STATE_FLAG_NORMAL);
+
+  if (!(selection = glade_project_selection_get (project)))
+    return;
+
+  glade_design_view_update_state (selection, GTK_STATE_FLAG_SELECTED);
+
   /* Check if its only one widget selected and scroll viewport to show toplevel */
-  if ((selection = glade_project_selection_get (project)) &&
-      g_list_next (selection) == NULL &&
-      GTK_IS_WIDGET (selection->data))
+  if (g_list_next (selection) == NULL &&
+      GTK_IS_WIDGET (selection->data) &&
+      (layout = gtk_widget_get_ancestor (selection->data, GLADE_TYPE_DESIGN_LAYOUT)))
     {
-      GladeWidget *gwidget, *gtoplevel;
-      GObject *toplevel;
-      
-      if (!GLADE_IS_PLACEHOLDER (selection->data) &&
-          (gwidget = glade_widget_get_from_gobject (G_OBJECT (selection->data))) &&
-          (gtoplevel = glade_widget_get_toplevel (gwidget)) &&
-          (toplevel = glade_widget_get_object (gtoplevel)) &&
-          GTK_IS_WIDGET (toplevel))
-        {
-          GtkWidget *layout;
+      GtkAllocation alloc;
+      gtk_widget_get_allocation (layout, &alloc);
 
-          if ((layout = gtk_widget_get_parent (GTK_WIDGET (toplevel))) &&
-              GLADE_IS_DESIGN_LAYOUT (layout))
-            {
-              GtkAllocation alloc;
-              gtk_widget_get_allocation (layout, &alloc);
-
-              if (alloc.x < 0)
-                g_signal_connect (layout, "size-allocate", G_CALLBACK (on_layout_size_allocate), view);
-              else
-                glade_design_layout_scroll (view, alloc.x, alloc.y, alloc.width, alloc.height);
-            }
-        }
+      if (alloc.x < 0)
+        g_signal_connect (layout, "size-allocate", G_CALLBACK (on_layout_size_allocate), view);
+      else
+        glade_design_layout_scroll (view, alloc.x, alloc.y, alloc.width, alloc.height);
     }
 }
 
@@ -760,27 +771,6 @@ glade_design_view_class_init (GladeDesignViewClass *klass)
                                                         G_PARAM_CONSTRUCT_ONLY));
 }
 
-/* Private API */
-void
-_glade_design_view_freeze (GladeDesignView *view)
-{
-  g_return_if_fail (GLADE_IS_DESIGN_VIEW (view));
-  
-  g_signal_handlers_block_by_func (view->priv->project,
-                                   glade_design_view_selection_changed,
-                                   view);
-}
-
-void
-_glade_design_view_thaw   (GladeDesignView *view)
-{
-  g_return_if_fail (GLADE_IS_DESIGN_VIEW (view));
-  
-  g_signal_handlers_unblock_by_func (view->priv->project,
-                                     glade_design_view_selection_changed,
-                                     view);
-}
-
 /* Public API */
 
 GladeProject *
