@@ -64,6 +64,7 @@ enum
   PROP_WIDGET,
   PROP_SHOW_CLASS_FIELD,
   PROP_CLASS_FIELD,
+  PROP_SHOW_BORDER,
   N_PROPERTIES
 };
 
@@ -163,6 +164,10 @@ glade_editor_set_property (GObject      *object,
         else
           glade_editor_hide_class_field (editor);
         break;
+      case PROP_SHOW_BORDER:
+        gtk_notebook_set_show_border (GTK_NOTEBOOK (editor->priv->notebook),
+                                      g_value_get_boolean (value));
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -191,6 +196,9 @@ glade_editor_get_property (GObject    *object,
       case PROP_CLASS_FIELD:
         g_value_set_static_string (value, gtk_label_get_label (GTK_LABEL (editor->priv->class_label)));
         break;
+      case PROP_SHOW_BORDER:
+        g_value_set_boolean (value, gtk_notebook_get_show_border (GTK_NOTEBOOK (editor->priv->notebook)));
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -251,6 +259,12 @@ glade_editor_class_init (GladeEditorClass *klass)
                          _("The class field string"),
                          NULL,
                          G_PARAM_READABLE);
+  properties[PROP_SHOW_BORDER] =
+    g_param_spec_boolean ("show-boder",
+                          _("Show Border"),
+                          _("Whether the border should be shown"),
+                          TRUE,
+                          G_PARAM_READWRITE);
   
   /* Install all properties */
   g_object_class_install_properties (object_class, N_PROPERTIES, properties);
@@ -303,11 +317,26 @@ glade_editor_update_class_field (GladeEditor *editor)
                                     GTK_ICON_SIZE_BUTTON);
       gtk_widget_show (priv->class_icon);
 
-      /* translators: referring to the properties of a widget named '%s [%s]' */
-      text = g_strdup_printf (_("%s Properties - %s [%s]"),
-                              glade_widget_adaptor_get_title (priv->loaded_adaptor),
-                              glade_widget_adaptor_get_name (priv->loaded_adaptor), 
-			      glade_widget_get_name (widget));
+      if (glade_widget_has_name (widget))
+        {
+          /* translators: %s(Class Title) Properties - %s (ClassName) [%s(WidgetName)]
+           * example: Window Properties - GtkWindow [window1]
+           */
+          text = g_strdup_printf (_("%s Properties - %s [%s]"),
+                                  glade_widget_adaptor_get_title (priv->loaded_adaptor),
+                                  glade_widget_adaptor_get_name (priv->loaded_adaptor), 
+		                  glade_widget_get_display_name (widget));
+        }
+      else
+        {
+          /* translators: %s(Class Title) Properties - %s (ClassName)
+           * example: Window Properties - GtkWindow
+           */
+          text = g_strdup_printf (_("%s Properties - %s"),
+                                  glade_widget_adaptor_get_title (priv->loaded_adaptor),
+                                  glade_widget_adaptor_get_name (priv->loaded_adaptor));
+	}
+		 
       gtk_label_set_text (GTK_LABEL (priv->class_label), text);
       g_free (text);
 
@@ -1256,6 +1285,22 @@ glade_editor_hide_class_field (GladeEditor *editor)
     }
 }
 
+static void
+editor_widget_name_changed (GladeWidget *widget,
+			    GParamSpec  *pspec,
+			    GtkWindow   *window)
+{
+  gchar *title, *prj_name;
+
+  prj_name = glade_project_get_name (glade_widget_get_project (widget));
+  /* Translators: first %s is the project name, second is a widget name */
+  title = g_strdup_printf (_("%s - %s Properties"), prj_name,
+                           glade_widget_get_display_name (widget));
+  gtk_window_set_title (window, title);
+  g_free (title);
+  g_free (prj_name);
+}
+
 /**
  * glade_editor_dialog_for_widget:
  * @widget: a #GladeWidget
@@ -1269,7 +1314,6 @@ GtkWidget *
 glade_editor_dialog_for_widget (GladeWidget *widget)
 {
   GtkWidget *window, *editor;
-  gchar *title, *prj_name;
 
   g_return_val_if_fail (GLADE_IS_WIDGET (widget), NULL);
 
@@ -1277,13 +1321,10 @@ glade_editor_dialog_for_widget (GladeWidget *widget)
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_type_hint (GTK_WINDOW (window), GDK_WINDOW_TYPE_HINT_UTILITY);
 
-  prj_name = glade_project_get_name (glade_widget_get_project (widget));
-  /* Translators: first %s is the project name, second is a widget name */
-  title = g_strdup_printf (_("%s - %s Properties"), prj_name,
-                           glade_widget_get_name (widget));
-  gtk_window_set_title (GTK_WINDOW (window), title);
-  g_free (title);
-  g_free (prj_name);
+  /* Keep the title up to date */
+  editor_widget_name_changed (widget, NULL, GTK_WINDOW (window));
+  g_signal_connect_object (G_OBJECT (widget), "notify::name",
+			   G_CALLBACK (editor_widget_name_changed), window, 0);
 
   if (glade_app_get_accel_group ())
     {
