@@ -712,8 +712,11 @@ glade_property_class_make_object_from_string (GladePropertyClass *
 
       if ((pixbuf = gdk_pixbuf_new_from_file (fullpath, NULL)) == NULL)
         {
-          pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-                                             "image-missing", 22, 0, NULL);
+          GdkPixbuf *icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+                                                      "image-missing", 22, 0, NULL);
+          /* Use a copy, since gtk_icon_theme_load_icon() returns the same pixbuf */
+          pixbuf = gdk_pixbuf_copy (icon);
+          g_object_unref (icon);
         }
 
       if (pixbuf)
@@ -867,10 +870,12 @@ glade_property_class_make_gvalue_from_string (GladePropertyClass *property_class
     g_value_set_uint (value, g_utf8_get_char (string));
   else if (G_IS_PARAM_SPEC_BOOLEAN (property_class->pspec))
     {
-      if (strcmp (string, GLADE_TAG_TRUE) == 0)
-        g_value_set_boolean (value, TRUE);
-      else
+      gboolean val;
+      if (glade_utils_boolean_from_string (string, &val))
         g_value_set_boolean (value, FALSE);
+      else
+        g_value_set_boolean (value, val);
+
     }
   else if (G_IS_PARAM_SPEC_OBJECT (property_class->pspec))
     {
