@@ -55,7 +55,16 @@ glade_gtk_container_add_verify (GladeWidgetAdaptor *adaptor,
       if (user_feedback)
 	glade_util_ui_message (glade_app_get_window (),
 			       GLADE_UI_INFO, NULL,
-			       _("Cannot add a toplevel window to a containter."));
+			       _("Cannot add a toplevel window to a container."));
+
+      return FALSE;
+    }
+  else if (GTK_IS_POPOVER (child))
+    {
+      if (user_feedback)
+	glade_util_ui_message (glade_app_get_window (),
+			       GLADE_UI_INFO, NULL,
+			       _("Cannot add a popover to a container."));
 
       return FALSE;
     }
